/*
 *  Copyright (C) 1999, 2000  Heikki Tauriainen <Heikki.Tauriainen@hut.fi>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "TestStatistics.h"

/******************************************************************************
 *
 * Function definitions for struct AutomatonStats.
 *
 *****************************************************************************/

/* ========================================================================= */
void AutomatonStats::reset()
/* ----------------------------------------------------------------------------
 *
 * Description:   Resets the contents of an AutomatonStats structure.
 *
 * Arguments:     None.
 *
 * Returns:       Nothing.
 *
 * ------------------------------------------------------------------------- */
{
  number_of_buchi_states = 0;
  number_of_buchi_transitions = 1;
  number_of_msccs = 0;
  buchi_generation_time = 0.0;
  number_of_product_states = 0;
  number_of_product_transitions = 1;
  emptiness_check_result = 0;
  path_check_result = -1;

  for (vector<StatPair, ALLOC(StatPair) >::iterator
	 it = cross_comparison_stats.begin();
       it != cross_comparison_stats.end();
       ++it)
  {
    it->first = false;
    it->second = 0;
  }
}



/******************************************************************************
 *
 * Function definitions for struct AlgorithmTestResults.
 *
 *****************************************************************************/

/* ========================================================================= */
void AlgorithmTestResults::reset()
/* ----------------------------------------------------------------------------
 *
 * Description:   Resets the contents of an AlgorithmTestResults structure.
 *
 * Arguments:     None.
 *
 * Returns:       Nothing.
 *
 * ------------------------------------------------------------------------- */
{
  consistency_check_result = -1;
  consistency_check_comparisons = 0;
  failed_consistency_check_comparisons = 0;

  automaton_stats[0].reset();
  automaton_stats[1].reset();
}
