// Copyright (C) 1998 Mauno Rnkk <mronkko@abo.fi>
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


#ifndef __CString_h__

#define __CString_h__

#include <stdlib.h>
#include <string.h>
#include <iostream.h>

//
//  This is for PC-compatibility only:
//
//  typedef enum BOOLEAN {false=0, true=1} bool;
//

/**
 *  A class for char strings.
 *
 *
 * Internally strings are stored as standard ASCIZ char pointers.
 *
 *
 * This class provides:
 * creation/destruction, assignment, concatenations,
 * comparisons, conversion to char*, and output to cout.
 **/
class CString {
 private:
  char *m_s;
  
 public:
  /// Create an empty string.
  CString ()
    { m_s=strdup(""); }
  
  /// Create a string from a char pointer.
  CString (const char *s)
    { m_s=strdup(s); }
  
  /// Create a string from a CString.
  CString (const CString& cs)
    { m_s=strdup(cs.m_s); }
  
  /// Frees the string from memory.
  ~CString ()
    { free (m_s); }
  
  /// Copy the content from a CString.
  const CString& operator = (const CString& cs);
  
  /// Appends the content of another CString.
  const CString& operator += (const CString& cs);
  
  /// Returns the catenation of two CStrings.
  friend const CString operator + (const CString& as, const CString& bs);
  
  /// Are two CStrings equivalent?
  const bool operator == (const CString& cs) const
    { return strcmp (m_s, cs.m_s)==0 ? true : false; }
  
  /// Is this less than another CStrings?
  const bool operator < (const CString& cs) const
    { return strcmp (m_s, cs.m_s)<0 ? true : false; }
  
  /// Are two CStrings not equivalent?
  const bool operator != (const CString& cs) const
    { return *this==cs ? false : true; }
  
  /// Returns a pointer to contents. May not be altered.
  const char *val () const
    { return m_s; }
  
  /// Output CString to ostream.
  friend ostream& operator << (ostream& str, const CString& s);
};


#endif

